.. image:: https://travis-ci.com/focusate/footil.svg?branch=master
    :target: https://travis-ci.com/focusate/footil

Various helper modules
======================

- **date** - date manipulation helpers.
- **decor** - helper decorators.
- **log** - helpers with stdout, stderr management, logging setup.
- **formatting** - string formatting.
- **path** - functions for paths manipulation.
- **xtyping** - type checking.

Source code in:

* `github <https://github.com/focusate/footil/>`_.
* `pypi <https://pypi.org/project/footil/>`_.

Contributors
============

* Silvija Butko (Focusate)
* Andrius Laukavičius (Focusate)
